import { Host, h } from "@stencil/core";
import { SVGSYM } from './sym';
export class SVGFloorplan {
    constructor() {
        /**
         * The width for the SVG element.
         */
        this.width = '4800';
        /**
         * The height for the SVG element.
         */
        this.height = '2400';
        /**
         * The height of the SVG viewbox.
         */
        this.vbWidth = this.width;
        /**
         * The width of the SVG viewbox.
         */
        this.vbHeight = this.height;
        /**
         * Setting to true adds a viewbox attribute to the SVG element.
         */
        this.useViewbox = false;
        /**
         * The ID of the active (selected) element.
         */
        this.activeId = '';
    }
    onActiveIdChange(newVal, oldVal) {
        if (newVal !== oldVal && this.svgRoot !== undefined) {
            const selected = this.svgRoot.querySelector('.rl-svg-floorplan--selected');
            if (selected !== null) {
                selected.classList.remove('rl-svg-floorplan--selected');
            }
            if (newVal !== '') {
                const active = this.svgRoot.querySelector(`#${newVal}`);
                if (active !== null) {
                    active.classList.add('rl-svg-floorplan--selected');
                }
            }
        }
    }
    render() {
        const SVG = this.svg !== undefined ? this.svg : () => ([
            h("text", { x: "50%", y: "50%", style: { 'font-size': '72px', 'text-anchor': 'middle' } }, "No SVG Specified"),
        ]);
        return (h(Host, { class: "rl-svg-floorplan" },
            h("svg", { width: this.width, height: this.height, viewBox: this.useViewbox ? `0 0 ${this.vbWidth} ${this.vbHeight}` : undefined, class: "rl-svg-floorplan__svg", ref: e => this.svgRoot = e, onClick: (e) => {
                    if (e.target instanceof SVGElement && e.target.classList.contains('rl-clickable')) {
                        this.rlElementClicked.emit(e.target.id);
                    }
                    else {
                        this.rlElementCleared.emit();
                    }
                } },
                h(SVGSYM, null),
                h("g", null,
                    h(SVG, null)))));
    }
    static get is() { return "rl-svg-floorplan"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["svg-floorplan.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["svg-floorplan.css"]
    }; }
    static get properties() { return {
        "svg": {
            "type": "unknown",
            "mutable": false,
            "complexType": {
                "original": "FunctionalComponent",
                "resolved": "FunctionalComponent<{}> | undefined",
                "references": {
                    "FunctionalComponent": {
                        "location": "import",
                        "path": "@stencil/core"
                    }
                }
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "The contents of the SVG, as a `FunctionalComponent`."
            }
        },
        "width": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The width for the SVG element."
            },
            "attribute": "width",
            "reflect": false,
            "defaultValue": "'4800'"
        },
        "height": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The height for the SVG element."
            },
            "attribute": "height",
            "reflect": false,
            "defaultValue": "'2400'"
        },
        "vbWidth": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The height of the SVG viewbox."
            },
            "attribute": "vb-width",
            "reflect": false,
            "defaultValue": "this.width"
        },
        "vbHeight": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The width of the SVG viewbox."
            },
            "attribute": "vb-height",
            "reflect": false,
            "defaultValue": "this.height"
        },
        "useViewbox": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Setting to true adds a viewbox attribute to the SVG element."
            },
            "attribute": "use-viewbox",
            "reflect": false,
            "defaultValue": "false"
        },
        "activeId": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The ID of the active (selected) element."
            },
            "attribute": "active-id",
            "reflect": false,
            "defaultValue": "''"
        }
    }; }
    static get events() { return [{
            "method": "rlElementClicked",
            "name": "rlElementClicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Event fired when an element in the SVG is clicked (if it is clickable).\nDetails will be the `id` of the clicked element."
            },
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            }
        }, {
            "method": "rlElementCleared",
            "name": "rlElementCleared",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Event fired when the SVG is clicked but no specific element is targeted,\nthat is, the active element is cleared."
            },
            "complexType": {
                "original": "void",
                "resolved": "void",
                "references": {}
            }
        }]; }
    static get elementRef() { return "root"; }
    static get watchers() { return [{
            "propName": "activeId",
            "methodName": "onActiveIdChange"
        }]; }
}
